@@ -17,22 +17,25 @@
 //! ```
 
 /// Usage: `static_file!(root, "index.html", "text/html")`
+
+pub mod content_types;
 #[macro_export]
 macro_rules! static_file {
     ($name:ident, $path:literal, $ctype:literal) => {
-        pub async fn $name() -> (axum::http::StatusCode, axum::http::HeaderMap, Vec<u8>) {
+        pub async fn $name() -> (axum::http::StatusCode, axum::http::HeaderMap, String) {
             let mut headers = axum::http::HeaderMap::new();
             headers.insert(
                 axum::http::header::CONTENT_TYPE,
                 axum::http::HeaderValue::from_static($ctype),
             );
             #[cfg(not(debug_assertions))]
-            let file = include_bytes!($path).to_vec();
+            let file = include_str!($path).to_string();
             #[cfg(debug_assertions)]
-            let file = tokio::fs::read(concat!("src/", $path))
+            let file = tokio::fs::read_to_string(concat!("src/", $path))
                 .await
                 .expect(concat!("Program is in debug mode and the ", $path, " file was not found!"));
             (axum::http::StatusCode::OK, headers, file)
         }
     };
 }
+
